@@ -1,10 +1,10 @@
+from django.http import HttpResponse
 from django.core.exceptions import ImproperlyConfigured
 from avocado.conf import OPTIONAL_DEPS
 if not OPTIONAL_DEPS['openpyxl']:
     raise ImproperlyConfigured('openpyxl must be installed to use this exporter.')
 
 from openpyxl import Workbook
-from openpyxl.writer.excel import save_virtual_workbook
 from _base import BaseExporter
 
 
@@ -16,23 +16,10 @@ class ExcelExporter(BaseExporter):
     def write(self, iterable, buff=None):
         buff = self.get_file_obj(buff)
 
-        # Create the workbook and sheets
         wb = Workbook(optimized_write=True)
+
         ws_data = wb.create_sheet()
         ws_data.title = 'Data'
-        ws_dict = wb.create_sheet()
-        ws_dict.title = 'Data Dictionary'
-
-        # Create the Data Dictionary Worksheet
-        ws_dict.append(('Field Name', 'Data Type', 'Description',
-            'Concept Name', 'Concept Discription'))
-
-        for c in self.concepts:
-            cfields = c.concept_fields.select_related('field')
-            for cfield in cfields:
-                datafield = cfield.field
-                ws_dict.append((datafield.field_name, datafield.simple_type,
-                    datafield.description, c.name, c.description))
 
         header = []
         # Create the data worksheet
@@ -49,9 +36,29 @@ class ExcelExporter(BaseExporter):
                 ws_data.append(header)
             ws_data.append(row)
 
-        # Save the workbook
-        if isinstance(buff, file):
-            wb.save(buff)
+        ws_dict = wb.create_sheet()
+        ws_dict.title = 'Data Dictionary'
+
+        # Create the Data Dictionary Worksheet
+        ws_dict.append(('Field Name', 'Data Type', 'Description',
+            'Concept Name', 'Concept Discription'))
+
+        for c in self.concepts:
+            cfields = c.concept_fields.select_related('field')
+            for cfield in cfields:
+                field = cfield.field
+                ws_dict.append((field.field_name, field.simple_type,
+                    field.description, c.name, c.description))
+
+        # This hacked up implementation is due to `save_virtual_workbook`
+        # not behaving correctly. This function should handle the work
+        # https://bitbucket.org/ericgazoni/openpyxl/src/94b05cf9defb9787b4dfbf9e8dca7ba6e0b33d56/openpyxl/writer/excel.py?at=default#cl-154
+        # however, no data is actually being saved to the worksheets..
+        if isinstance(buff, HttpResponse):
+            _buff = self.get_file_obj()
+            wb.save(_buff)
+            buff.content = _buff.getvalue()
+            _buff.close()
         else:
-            buff.write(save_virtual_workbook(wb))
+            wb.save(buff)
         return buff
